@@ -19,11 +19,25 @@
 # -*- coding: utf-8 -*-
 """pylivemaker cli."""
 
-from .cli import galconvert
+import os
+import sys
+
+from loguru import logger
+
+from .cli import galconvert, lmbmp
 from .lmar import lmar
 from .lmgraph import lmgraph
 from .lmlpb import lmlpb
 from .lmlsb import lmlsb
 from .lmpatch import lmpatch
 
-__all__ = ["galconvert", "lmar", "lmgraph", "lmlpb", "lmlsb", "lmpatch"]
+__all__ = ["galconvert", "lmar", "lmbmp", "lmgraph", "lmlpb", "lmlsb", "lmpatch"]
+
+
+logger.remove()
+
+if os.name == "nt":
+    sys.stdout.reconfigure(encoding="utf-8", errors="backslashreplace")
+
+logger.add(sys.stderr, level="WARNING")
+logger.enable("livemaker")
