@@ -61,11 +61,45 @@ def galconvert(force, input_file, output_file):
     """
     try:
         im = Image.open(input_file)
-    except IOError as e:
-        raise e
-        # sys.exit('Error opening {}: {}'.format(input_file, e))
+    except OSError as e:
+        sys.exit(f"Error opening {input_file}: {e}")
     if Path(output_file).exists() and not force:
-        sys.exit("{} already exists".format(output_file))
-    print("Converting {} to {}".format(input_file, output_file))
+        sys.exit(f"{output_file} already exists")
+    print(f"Converting {input_file} to {output_file}")
     im.load()
     im.save(output_file)
+
+
+@click.command()
+@click.version_option(version=__version__, message=_version)
+@click.option("-f", "--force", is_flag=True, default=False, help="Overwrite output file if it exists.")
+@click.argument("input_file", required=True, type=click.Path(exists=True, dir_okay=False))
+def lmbmp(force, input_file):
+    """Convert image to BMP(s) which can be used with bmp2gale.
+
+    If the input file contains an alpha layer, a mask bitmap will be generated.
+    Output files will be named <input_name>.bmp and <input_name>-m.bmp.
+    """
+    input_file = Path(input_file)
+    try:
+        im = Image.open(input_file)
+    except IOError as e:
+        sys.exit(f"Error opening {input_file}: {e}")
+    name = Path(input_file.stem)
+    output_file = input_file.parent / f"{name}.bmp"
+    if Path(output_file).exists() and not force:
+        sys.exit(f"{output_file} already exists")
+
+    try:
+        mask = im.getchannel("A")
+        output_mask = input_file.parent / f"{name}-m.bmp"
+        if Path(output_mask).exists() and not force:
+            sys.exit(f"{output_mask} already exists")
+        print(f"Generating mask {output_mask}")
+        mask.save(output_mask)
+    except ValueError:
+        pass
+
+    print(f"Converting {input_file} to {output_file}")
+    im = im.convert("RGB")
+    im.save(output_file)
